Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(123)

Unified Diff: content/renderer/media/stream_texture_factory_impl_android.cc

Issue 12902002: Remove WebVideoFrame, WebVideoFrameProvider, and WebVideoLayer. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: No provider client lock Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/media/stream_texture_factory_impl_android.cc
diff --git a/content/renderer/media/stream_texture_factory_impl_android.cc b/content/renderer/media/stream_texture_factory_impl_android.cc
index ebfae209dac27d9312a76bc69f3f7e7884e7a5c1..ab3813f80ede84d4e9dd77c7de26eadc1c30b340 100644
--- a/content/renderer/media/stream_texture_factory_impl_android.cc
+++ b/content/renderer/media/stream_texture_factory_impl_android.cc
@@ -13,7 +13,6 @@
#include "content/common/gpu/gpu_messages.h"
#include "content/renderer/render_thread_impl.h"
#include "third_party/WebKit/Source/Platform/chromium/public/WebGraphicsContext3D.h"
-#include "third_party/WebKit/Source/WebKit/chromium/public/WebStreamTextureClient.h"
#include "ui/gfx/size.h"
namespace {
@@ -23,7 +22,8 @@ static void DeleteStreamTextureHost(content::StreamTextureHost* host) {
}
// Implementation of the StreamTextureProxy class. This class listens to all
// the stream texture updates and forward them to the WebStreamTextureClient.
class StreamTextureProxyImpl : public webkit_media::StreamTextureProxy,
public content::StreamTextureHost::Listener {
public:
@@ -33,7 +33,7 @@ class StreamTextureProxyImpl : public webkit_media::StreamTextureProxy,
// webkit_media::StreamTextureProxy implementation:
virtual bool Initialize(int stream_id, int width, int height) OVERRIDE;
virtual bool IsInitialized() OVERRIDE { return initialized_; }
- virtual void SetClient(WebKit::WebStreamTextureClient* client) OVERRIDE;
+ virtual void SetClient(cc::VideoFrameProvider::Client* client) OVERRIDE;
// StreamTextureHost::Listener implementation:
virtual void OnFrameAvailable() OVERRIDE;
@@ -44,7 +44,7 @@ class StreamTextureProxyImpl : public webkit_media::StreamTextureProxy,
scoped_refptr<base::MessageLoopProxy> loop_;
base::Lock client_lock_;
- WebKit::WebStreamTextureClient* client_;
+ cc::VideoFrameProvider::Client* client_;
bool initialized_;
DISALLOW_COPY_AND_ASSIGN(StreamTextureProxyImpl);
@@ -69,7 +69,7 @@ StreamTextureProxyImpl::~StreamTextureProxyImpl() {
}
}
-void StreamTextureProxyImpl::SetClient(WebKit::WebStreamTextureClient* client) {
+void StreamTextureProxyImpl::SetClient(cc::VideoFrameProvider::Client* client) {
base::AutoLock lock(client_lock_);
client_ = client;
}
@@ -83,13 +83,13 @@ bool StreamTextureProxyImpl::Initialize(int stream_id, int width, int height) {
void StreamTextureProxyImpl::OnFrameAvailable() {
base::AutoLock lock(client_lock_);
if (client_)
- client_->didReceiveFrame();
+ client_->DidReceiveFrame();
}
void StreamTextureProxyImpl::OnMatrixChanged(const float matrix[16]) {
base::AutoLock lock(client_lock_);
if (client_)
- client_->didUpdateMatrix(matrix);
+ client_->DidUpdateMatrix(matrix);
}
} // anonymous namespace
@@ -23,7 +22,8 @@ static void DeleteStreamTextureHost(content::StreamTextureHost* host) {
}
// Implementation of the StreamTextureProxy class. This class listens to all
-// the stream texture updates and forward them to the WebStreamTextureClient.
+// the stream texture updates and forward them to the
+// cc::VideoFrameProvider::Client.
class StreamTextureProxyImpl : public webkit_media::StreamTextureProxy,
public content::StreamTextureHost::Listener {

Powered by Google App Engine
This is Rietveld 408576698